import { LevelResolver, shouldLog } from './level-resolver.js';

/**
 * A Logger using console output.
 *
 * @param logLevel - The logger level name
 * @param prefix - An optional logger message prefix
 * @param output - The output to print logs, using by default the global console object
 *
 * @internal
 */
class ConsoleLogger {
  constructor(logLevel, prefix = '', output = console) {
    this.logLevel = logLevel;
    this.prefix = prefix;
    this.output = output;
    this.level = LevelResolver[this.logLevel];
  }
  makeMethod(method) {
    return message => {
      if (shouldLog(this.level, method)) {
        this.output[method](this.prefix ? `${this.prefix} ${message}` : message);
      }
    };
  }
  debug = this.makeMethod('debug');
  error = this.makeMethod('error');
  info = this.makeMethod('info');
  warn = this.makeMethod('warn');
}

export { ConsoleLogger };
